#!/bin/sh

preinstall() {
	WS1_USER_NAME=ws1user
	WS1_GROUP_NAME=ws1user
	id -u $WS1_USER_NAME 2>/dev/null
	if [ $? -ne 0 ]; then
	    echo "User \"$WS1_USER_NAME\" does not exist. Creating..."
	    useradd -U -M $WS1_GROUP_NAME
	    echo "Created user \"$WS1_USER_NAME\""
	fi
	
}

install() {
	if [ -f /opt/vmware/ws1-hub/bin/ws1HubAgent ]; then
	   rm -rf /var/backups/ws1data_backup
	   mkdir -p /var/backups
	   cp -r /opt/vmware/ws1-hub/data/ /var/backups/ws1data_backup
	   /opt/vmware/ws1-hub/agent stop
	fi
	if [ ! -d "/opt/vmware" ]; then
	  mkdir /opt/vmware
	fi
	cp -r ${PWD}/rootfs/opt/vmware/ws1-hub /opt/vmware
	cp -r uninstall.sh /opt/vmware/ws1-hub
	rm -r ${PWD}/rootfs
	rm  uninstall.sh
	
}

postinstall() {
	WS1_USER_NAME=ws1user
	WS1_GROUP_NAME=ws1user
	mkdir -p /var/log/ws1-hub/
	if [ -d /var/backups/ws1data_backup ]; then
	    cp -r /var/backups/ws1data_backup/* /opt/vmware/ws1-hub/data
	    rm -rf /var/backups/ws1data_backup
	fi
	chown -R $WS1_USER_NAME:$WS1_GROUP_NAME /opt/vmware/ws1-hub
	chown -R $WS1_USER_NAME:$WS1_GROUP_NAME /var/log/ws1-hub/
	chmod u=rxs,g=rxs,o=r /opt/vmware/ws1-hub/bin/ws1HubAgent
	/opt/vmware/ws1-hub/bin/ws1HubUtil upgrade --db-only \
	    --version "21.10.0.1"
	/opt/vmware/ws1-hub/script/ws1HubSetup.sh -owner $WS1_USER_NAME \
	    -version "21.10.0.1"
	/opt/vmware/ws1-hub/bin/ws1HubUtil puppet --install
	/opt/vmware/ws1-hub/bin/ws1HubUtil enroll --continue-using-cookie
	rm -f install.sh
	
}

checkupgradeversion() {
	# If Hub agent is already installed, check if this installer
	# is of higher version for upgrade.
	#############################################################################################
	if [ -f "/etc/ws1-hub.conf" ]; then
	    WS1HOME=$(awk -F '[<>]' '/home/ {print $3}' /etc/ws1-hub.conf)
	    if [ -d "$WS1HOME" ]; then
	        echo "ws1Hub agent exists already"
	        OKAY_FOR_UPGRADE='N'
	        nv="21.10.0.1"
	        ov=$( awk -F'[<>]' '/<Version>/{print $3}' \
	          $WS1HOME/config/GeneralConfig.conf )
	        echo "old version - $ov , new version - $nv"
	
	        NF=$(echo $ov | awk -F . '{print NF}')
	        i=1
	        while [ $i -le $NF ]; do
	            n=$(expr $(echo $nv | awk -F . '{print $i}' i=$i) + 0)
	            o=$(expr $(echo $ov | awk -F . '{print $i}' i=$i) + 0)
	            if [ $n -gt $o ]; then
	                echo "older version detected"
	                OKAY_FOR_UPGRADE='Y'
	                break
	            fi
	            i=$((i + 1))
	        done
	        if [ "$OKAY_FOR_UPGRADE" = "Y" ]; then
	            echo "Installing newer version"
	        else
	            echo "already newer version is installed"
	            return 1
	        fi
	        return $?
	    fi
	fi
	
}

checkupgradeversion
if [ $? -eq 0 ]; then
preinstall
install
postinstall
fi
